@@ -152,11 +152,11 @@ setMethod("as.vector", signature(x = "ldenseMatrix", mode = "missing"),
 	  function(x) as(x, "lgeMatrix")@x)
 
 setMethod("all", signature(x = "lsyMatrix"),
-          function(x, ..., na.rm = TRUE)
+          function(x, ..., na.rm = FALSE)
           all(x@x, ..., na.rm = na.rm))
 ## Note: the above "lsy*" method is needed [case below can be wrong]
 setMethod("all", signature(x = "ldenseMatrix"),
-	  function(x, ..., na.rm = TRUE) {
+	  function(x, ..., na.rm = FALSE) {
 	      if(prod(dim(x)) >= 1)
 		  (!is(x, "triangularMatrix") && !is(x, "diagonalMatrix") &&
 		   all(x@x, ..., na.rm = na.rm))
@@ -164,6 +164,6 @@ setMethod("all", signature(x = "ldenseMatrix"),
 	  })
 
 setMethod("any", signature(x = "ldenseMatrix"),
-	  function(x, ..., na.rm = TRUE)
+	  function(x, ..., na.rm = FALSE)
 	  (prod(dim(x)) >= 1 && is(x, "triangularMatrix") && x@diag == "U") ||
 	  any(x@x, ..., na.rm = na.rm))
